# Puppet module: puppetdb

This is a Puppet module for puppetdb based on the second generation layout ("NextGen") of Example42 Puppet Modules.

Made by Alessandro Franceschi / Lab42

Official site: http://www.example42.com

Official git repository: http://github.com/example42/puppet-puppetdb

Released under the terms of Apache 2 License.

This module requires functions provided by the Example42 Puppi module (you need it even if you don't use and install Puppi)

For detailed info about the logic and usage patterns of Example42 modules check the DOCS directory on Example42 main modules set.

## USAGE - Module's specific parameters

* Install PuppetDb with local postgresql backend (Note: default credentials with a random password are used)

        class { 'puppetdb':
          db_type => 'postgresql',
        }

* Install PuppetDb with postgresql backend and custom credentials

        class { 'puppetdb':
          db_type     => 'postgresql',
          db_host     => 'data.example42.com',
          db_port     => '12345',
          db_name     => 'puppetdb',
          db_user     => 'puppetdbuser',
          db_password => 's0rt0fP4ssW0rd!',
        }


## USAGE - Basic management

* Install puppetdb with default settings (hsqldb backend)

        class { 'puppetdb': }

* Install a specific version of puppetdb package

        class { 'puppetdb':
          version => '1.0.1',
        }

* Disable puppetdb service.

        class { 'puppetdb':
          disable => true
        }

* Remove puppetdb package

        class { 'puppetdb':
          absent => true
        }

* Enable auditing without without making changes on existing puppetdb configuration files

        class { 'puppetdb':
          audit_only => true
        }


## USAGE - Overrides and Customizations
* Use custom sources for main config file 

        class { 'puppetdb':
          source => [ "puppet:///modules/lab42/puppetdb/puppetdb.conf-${hostname}" , "puppet:///modules/lab42/puppetdb/puppetdb.conf" ], 
        }


* Use custom source directory for the whole configuration dir

        class { 'puppetdb':
          source_dir       => 'puppet:///modules/lab42/puppetdb/conf/',
          source_dir_purge => false, # Set to true to purge any existing file not present in $source_dir
        }

* Use custom template for main config file. Note that template and source arguments are alternative. 

        class { 'puppetdb':
          template => 'example42/puppetdb/puppetdb.conf.erb',
        }

* Automatically include a custom subclass

        class { 'puppetdb':
          my_class => 'puppetdb::example42',
        }


## USAGE - Example42 extensions management 
* Activate puppi (recommended, but disabled by default)

        class { 'puppetdb':
          puppi    => true,
        }

* Activate puppi and use a custom puppi_helper template (to be provided separately with a puppi::helper define ) to customize the output of puppi commands 

        class { 'puppetdb':
          puppi        => true,
          puppi_helper => 'myhelper', 
        }

* Activate automatic monitoring (recommended, but disabled by default). This option requires the usage of Example42 monitor and relevant monitor tools modules

        class { 'puppetdb':
          monitor      => true,
          monitor_tool => [ 'nagios' , 'monit' , 'munin' ],
        }

* Activate automatic firewalling. This option requires the usage of Example42 firewall and relevant firewall tools modules

        class { 'puppetdb':       
          firewall      => true,
          firewall_tool => 'iptables',
          firewall_src  => '10.42.0.0/24',
          firewall_dst  => $ipaddress_eth0,
        }


[![Build Status](https://travis-ci.org/example42/puppet-puppetdb.png?branch=master)](https://travis-ci.org/example42/puppet-puppetdb)
